@@ -10,6 +10,7 @@ use LWP::UserAgent;
 use Readonly;
 use XML::LibXML;
 use Params::Validate qw(:all);
+
 use WWW::Ohloh::API::Account;
 use WWW::Ohloh::API::Analysis;
 use WWW::Ohloh::API::Project;
@@ -21,9 +22,12 @@ use WWW::Ohloh::API::Kudos;
 use WWW::Ohloh::API::ContributorLanguageFact;
 use WWW::Ohloh::API::Enlistment;
 use WWW::Ohloh::API::Factoid;
+use WWW::Ohloh::API::SizeFact;
+use WWW::Ohloh::API::Stack;
+
 use Digest::MD5 qw/ md5_hex /;
 
-our $VERSION = '0.0.9';
+our $VERSION = '0.1.0';
 
 Readonly our $OHLOH_URL => 'http://www.ohloh.net/';
 
@@ -40,6 +44,64 @@ my @parser_of : Field;
 
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
+sub get_account_stack {
+    my $self = shift;
+
+    my $id = shift;
+
+    $id = md5_hex($id) if -1 < index $id, '@';    # it's an email
+
+    my ( $url, $xml ) =
+      $self->_query_server("accounts/$id/stacks/default.xml");
+
+    return WWW::Ohloh::API::Stack->new(
+        ohloh       => $self,
+        request_url => $url,
+        xml         => $xml->findnodes('stack[1]'),
+    );
+}
+
+#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
+sub get_project_stacks {
+    my $self = shift;
+
+    my $project = shift;
+
+    my ( $url, $xml ) = $self->_query_server("projects/$project/stacks.xml");
+
+    return map {
+        WWW::Ohloh::API::Stack->new(
+            ohloh       => $self,
+            request_url => $url,
+            xml         => $_,
+          )
+    } $xml->findnodes('//result/stack');
+}
+
+#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
+sub get_size_facts {
+    my $self = shift;
+
+    my ( $project_id, $analysis_id ) =
+      validate_pos( @_, 1, { default => 'latest' }, );
+
+    my ( $url, $xml ) = $self->_query_server(
+        "projects/$project_id/analyses/$analysis_id/size_facts.xml");
+
+    return map {
+        WWW::Ohloh::API::SizeFact->new(
+            ohloh       => $self,
+            request_url => $url,
+            xml         => $_
+          )
+    } $xml->findnodes('//size_fact');
+
+}
+
+#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
 sub get_account {
     my $self = shift;
 
@@ -411,6 +473,24 @@ contributor I<$c_id> for the project I<$p_id>.
 Return the list of L<WWW::Ohloh::API::Enlistment> objects pertaining to the
 given project.
 
+=head2 get_size_facts( $project_id, $analysis_id )
+
+Return the list of L<WWW::Ohloh::API::SizeFact> objects pertaining to the
+given project and analysis. If I<$analysis_id> is not provided, it defaults
+to the latest analysis done on the project.
+
+=head2 get_project_stacks( $project_id ) 
+
+Return the list of stacks containing the project as 
+L<WWW::Ohloh::API::Stack>
+objects.
+
+=head2 get_account_stack( $account_id )
+
+Return the stack associated with the account as an 
+L<WWW::Ohloh::API::Stack> object.
+
+
 =head1 SEE ALSO
 
 =over
@@ -436,7 +516,7 @@ How to obtain an Ohloh API key: http://www.ohloh.net/api_keys/new
 
 =head1 VERSION
 
-This document describes WWW::Ohloh::API version 0.0.9
+This document describes WWW::Ohloh::API version 0.1.0
 
 =head1 BUGS AND LIMITATIONS
 
